@@ -7,7 +7,9 @@ pub struct GitRepo {
 
 #[derive(Serialize, Deserialize)]
 pub struct GitCommit {
-    pub oid :String
+    pub oid :String,
+    pub message: String,
+    pub author: String
 }
 
 impl GitRepo {
@@ -22,7 +24,7 @@ impl GitRepo {
         
         Ok(GitRepo{repo})
     }
-
+    
     pub fn refresh(&self) -> Result<GitRepo, String> {
         let repo = Repository::open(self.repo.path());
         
@@ -46,9 +48,17 @@ impl GitRepo {
         let mut commits = Vec::new();
         
         revs.for_each(|rev| {
-            commits.push(GitCommit{oid: format!("{}", rev.unwrap())});
+            let oid_raw = rev.unwrap();
+            let oid = format!("{}", oid_raw);
+            let commit = self.repo.find_commit(oid_raw).unwrap();
+            let message = match commit.message() {
+                Some(message) => message.to_string(),
+                None => "".to_string()
+            };
+            let author = commit.author().to_string();
+            commits.push(GitCommit{oid, message, author});
         });
         
         commits
-    } 
+    }
 }
\ No newline at end of file
